Documentation
¶
Overview ¶
Package alert alert rules and templatize.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Alert ¶
type Alert struct {
Name string `yaml:"name"`
Interval string `yaml:"interval"`
SearchIndex string `yaml:"search_index"`
SearchType string `yaml:"search_type"`
Search search.Dict `yaml:"search"`
SearchQuery string `yaml:"search_query"`
Process luautil.LuaRunner `yaml:"process"`
Jobber *jobber.FullTimeSpec
SearchIndexTPL *template.Template
SearchTypeTPL *template.Template
SearchTPL *template.Template
}
Alert encompasses a search query which will be run periodically, the results of which will be checked against a condition. If the condition returns true a set of actions will be performed
func (Alert) CreateSearch ¶
Click to show internal directories.
Click to hide internal directories.